pub struct AlphaBatchBuilder {
pub alpha_batch_list: AlphaBatchList,
pub opaque_batch_list: OpaqueBatchList,
pub render_task_id: RenderTaskId,
render_task_address: RenderTaskAddress,
}Expand description
Encapsulates the logic of building batches for items that are blended.
Fields
alpha_batch_list: AlphaBatchListopaque_batch_list: OpaqueBatchListrender_task_id: RenderTaskIdrender_task_address: RenderTaskAddressImplementations
Sourceimpl AlphaBatchBuilder
impl AlphaBatchBuilder
pub fn new( screen_size: DeviceIntSize, break_advanced_blend_batches: bool, lookback_count: usize, render_task_id: RenderTaskId, render_task_address: RenderTaskAddress, memory: &FrameMemory, ) -> Self
Sourcefn clear(&mut self)
fn clear(&mut self)
Clear all current batches in this builder. This is typically used when a primitive is encountered that occludes all previous content in this batch list.
pub fn build( self, batch_containers: &mut Vec<AlphaBatchContainer, FrameAllocator>, merged_batches: &mut AlphaBatchContainer, task_rect: DeviceIntRect, task_scissor_rect: Option<DeviceIntRect>, )
pub fn push_single_instance( &mut self, key: BatchKey, features: BatchFeatures, bounding_rect: &PictureRect, z_id: ZBufferId, instance: PrimitiveInstanceData, )
pub fn set_params_and_get_batch( &mut self, key: BatchKey, features: BatchFeatures, bounding_rect: &PictureRect, z_id: ZBufferId, ) -> &mut Vec<PrimitiveInstanceData, FrameAllocator>