pub struct AlphaBatchList {
pub batches: Vec<PrimitiveBatch, FrameAllocator>,
pub batch_rects: Vec<BatchRects, FrameAllocator>,
current_batch_index: usize,
current_z_id: ZBufferId,
break_advanced_blend_batches: bool,
}Fields
batches: Vec<PrimitiveBatch, FrameAllocator>batch_rects: Vec<BatchRects, FrameAllocator>current_batch_index: usizecurrent_z_id: ZBufferIdbreak_advanced_blend_batches: boolImplementations
Sourceimpl AlphaBatchList
impl AlphaBatchList
fn new( break_advanced_blend_batches: bool, preallocate: usize, memory: &FrameMemory, ) -> Self
Sourcefn clear(&mut self)
fn clear(&mut self)
Clear all current batches in this list. This is typically used when a primitive is encountered that occludes all previous content in this batch list.
pub fn set_params_and_get_batch( &mut self, key: BatchKey, features: BatchFeatures, z_bounding_rect: &PictureRect, z_id: ZBufferId, ) -> &mut Vec<PrimitiveInstanceData, FrameAllocator>